import unittest

import kivysome
from kivysome import iconfonts


class Tests(unittest.TestCase):

    def test_kivy_awesome_regular(self):
        # DO NOT COPY THIS LINK!
        # Generate your own here: https://fontawesome.com/kits
        kivysome.enable("https://kit.fontawesome.com/23372bf9a2.js", force=True)

    def test_kivy_awesome_wrong_url(self):
        with self.assertRaises(ValueError):
            kivysome.enable("https://google.com")

    def test_kivy_awesome_invalid_url(self):
        with self.assertRaises(ValueError):
            kivysome.enable("invalid")

    def test_create_fontdict_file(self):
        res = iconfonts.create_fontdict_file("tests/iconfont_sample.css",
                                             'tests/iconfont_sample.fontd')
        self.assertEqual(res, {'icon-plus-circled': 59395, 'icon-spin6': 59393,
                               'icon-doc-text-inv': 59396,
                               'icon-emo-happy': 59392,
                               'icon-comment': 59397, 'icon-users': 59394})

    def test_register(self):
        iconfonts.register('name', 'tests/iconfont_sample.ttf',
                           'tests/iconfont_sample.fontd')
        self.assertEqual(iconfonts._register['name'][0], 'tests/iconfont_sample.ttf')

    def test_icon(self):
        iconfonts.register('name', 'tests/iconfont_sample.ttf',
                           'tests/iconfont_sample.fontd')
        r = iconfonts.icon('icon-comment')
        self.assertEqual(
            "[font=tests/iconfont_sample.ttf]%s[/font]" % chr(59397), r)
        r = iconfonts.icon('icon-comment', 20)
        self.assertEqual(
            "[size=20][font=tests/iconfont_sample.ttf]%s[/font][/size]" %
            chr(59397), r)



import json
from pathlib import Path
from typing import Optional, List

from setuptools import setup, find_packages


def get_dependencies(pipfile_lock: Optional[str] = None, develop: bool = False):
    if pipfile_lock is None:
        pipfile_lock = "Pipfile.lock"
    lock_data = json.load(Path(pipfile_lock).open())
    result: List[str] = [package_name for package_name in lock_data.get('default', {}).keys()]
    if develop:
        result += [package_name for package_name in lock_data.get('develop', {}).keys()]
    return result


setup(
    name="kivysome",
    packages=find_packages(),
    version_config={
        "template": "{tag}",
        "dev_template": "{tag}.dev{ccount}+git.{sha}",
        "dirty_template": "{tag}",
    },
    license="MIT",
    description="Font Awesome 5 Icons for Kivy",
    long_description=Path("README.md").read_text(),
    long_description_content_type="text/markdown",
    author="matfax",
    author_email="matthias.fax@gmail.com",
    url="https://github.com/matfax/kivysome",
    keywords=["kivy", "fa", "font", "awesome", "icons"],
    setup_requires=["setuptools-git-ver"],
    install_requires=get_dependencies(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    python_requires=">=3.7"
)
